@@ -2,11 +2,11 @@ import pathlib as _pathlib
 from importlib import metadata as _metadata
 
 try:
-    from reviser.interactivity import run_shell  # noqa
+    from reviser.interactivity import main_shell  # noqa: F401
 except ImportError as error:
     _stored_error = error
 
-    def run_shell(*args, **kwargs):  # type:ignore
+    def main_shell() -> None:
         """Replacement shell when import fails due to missing dependencies."""
         global _stored_error
         raise _stored_error
